/* 
** AUTHORS: 
** Rama Alebouyeh (rama[at]cs.ucsb.edu)
** Matthew S Allen (msa[at]cs.ucsb.edu)
*/

#ifndef _CHIMERA_ROUTE_H_
#define _CHIMERA_ROUTE_H_

#include "chimera.h"

/* route_init:
** Ininitiates routing table and leafsets */
void route_init(ChimeraHost *me);

/* route_lookup: key, count,is_safe
** returns an array of #count# nodes that are acceptable next hops for a
** message being routed to #key#. #is_save# is ignored for now. */

ChimeraHost **route_lookup(Key key, int count, int is_safe);


/* route_neighbors: count
** returns an array of #count# neighbor nodes with priority to closer nodes */

ChimeraHost **route_neighbors(int count);


/* route_update:host,joined
** updated the routing table in regard to #host#. If the host is joining
** the network (and #joined# == 1), then it is added to the routing table
** if it is appropriate. If it is leaving the network (and #joined# == 0),
** then it is removed from the routing tables */

void route_update(ChimeraHost *host, int joined);


/* route_row_lookup:key 
** return the row in the routing table that matches the longest prefix with #key# */

ChimeraHost **route_row_lookup(Key key);


/* route_get_table:
** returns all the entries in the routing table in an array of ChimeraHost */

ChimeraHost **route_get_table(void);

/* print routing table */
void printTable();

#endif /* _CHIMERA_ROUTE_H_ */
